@@ -70,6 +70,47 @@ permitted in the ``rose-suite.conf`` files:
    for ease of porting Cylc 7 workflows.
 
 
+Special Variables
+-----------------
+
+The Cylc Rose plugin provides two environment/template variables
+to the Cylc scheduler:
+
+``ROSE_ORIG_HOST``
+   Cylc commands (such as ``cylc install``, ``cylc validate`` and
+   ``cylc play``)
+   will provide the name of the host on which the command is run.
+
+   If the workflow is installed the value of ``ROSE_ORIG_HOST`` will be
+   set in ``opt/rose-suite-cylc-install.conf`` and used by future commands
+   e.g. ``cylc play``.
+
+   Using ``cylc install`` should produce a more consistent value
+   for ``ROSE_ORIG_HOST``; running Cylc commands on non-installed
+   workflows may produce inconsistent values because the host
+   is identified each time you run a command.
+
+
+``ROSE_VERSION``
+   When running Cylc commands such as ``cylc install``,
+   ``cylc play`` and ``cylc validate``
+   the plugin provides the version number of your installed Rose Version in
+   workflow scheduler's environment.
+
+   .. deprecated:: 8.0.0
+
+      Setting ``[env]ROSE_VERSION`` in ``rose-suite.conf``.
+      With Cylc 7 / Rose2019 users could set ``ROSE_VERSION`` for their
+      suites. This is no longer possible, and if set in your
+      ``ROSE_VERSION`` in your suite configuration it will be ignored.
+
+
+``CYLC_VERSION``
+   .. deprecated:: 8.0.0
+
+      ``CYLC_VERSION`` will be removed from your configuration by the
+      Cylc-Rose plugin, as it is now set by Cylc.
+
 Additional CLI options
 ----------------------
 You can use command line options to set or override
@@ -164,4 +205,4 @@ configuration file ``~/cylc-run/my_workflow/opt/rose-suite-cylc-install.conf``.
 
 """
 
-__version__ = '0.3.0'
+__version__ = '1.0.0'
