@@ -26,6 +26,7 @@ from pathlib import Path
 
 from metomi.rose.config import ConfigLoader, ConfigDumper
 from cylc.rose.utilities import (
+    ROSE_ORIG_HOST_INSTALLED_OVERRIDE_STRING,
     dump_rose_log,
     get_rose_vars_from_config_node,
     identify_templating_section,
@@ -188,13 +189,16 @@ def record_cylc_install_options(
                 oldconfig, cli_config
             )
 
-    # Get Values for standard ROSE variables (ROSE_ORIG_HOST and ROSE_SITE).
+    # Get Values for standard ROSE variable ROSE_ORIG_HOST.
     rose_orig_host = get_host()
     for section in [
         'env', 'jinja2:suite.rc', 'empy:suite.rc', 'template variables'
     ]:
         if section in cli_config:
             cli_config[section].set(['ROSE_ORIG_HOST'], rose_orig_host)
+            cli_config[section]['ROSE_ORIG_HOST'].comments = [
+                ROSE_ORIG_HOST_INSTALLED_OVERRIDE_STRING
+            ]
 
     cli_config.comments = [' This file records CLI Options.']
     identify_templating_section(cli_config)
